==> phpMyGPX-0.3.1.tar.bz2: phpmygpx/installation/install_db.php <==
<?php
/**
* @version $Id: $
* @package osm-things
* @copyright Copyright (C) 2008 Sebastian Klemm.
* @license http://www.gnu.org/copyleft/gpl.html GNU/GPL, see LICENSE.php
*/

define( '_VALID_OSM', TRUE );
define( '_PATH', '../' );
$DEBUG = FALSE;
if($DEBUG) error_reporting(E_ALL);

include("../config.inc.php");
include("../libraries/functions.inc.php");
include("../libraries/html.classes.php");

setlocale (LC_TIME, $cfg['config_locale']);
include("../languages/".get_lang($cfg['config_language']).".php");
include("../head.html.php");

$db_host = strip_tags($_POST['db_host']);
$db_user = strip_tags($_POST['db_user']);
$db_pass = strip_tags($_POST['db_pw']);
$upgrade = strip_tags($_POST['upgrade']);

HTML::heading(_INST_OSM_SETUP._INST_DB_INST, 3);
HTML::message(_INST_GUIDED);
?>

<ol start="1" type="1">
  <li id="done"><?php echo _INST_DB_ACCOUNT; ?><img src='images/tick_12.png'></li>
  <li id="current"><?php echo _INST_DB_CREATE_SETUP; ?></li>
  
  <?php HTML::message(_INST_PROG_INST); ?>

<?php
$mysql_err_count = 0;
// connect to database server
$link = mysql_connect($db_host, $db_user, $db_pass);
if(!$link) {
    out(_INST_DB_CONN_ERROR. mysql_error(), 3);
    $mysql_err_count++;
}else {

	// initial database installation: create database
	if(!$upgrade) {
		$query = "CREATE DATABASE IF NOT EXISTS `".$cfg['db_name']."`;";
		$result = mysql_query($query);
		if(!$result) {
		    out(_INST_DB_ERROR. mysql_error(), 3);
		    $mysql_err_count++;
		}
	}
	
	// select database
	if(!mysql_select_db($cfg['db_name'], $link)) {
	    out(_INST_DB_ERROR. mysql_error(), 3);
	    $mysql_err_count++;
	}
	
	// initial database installation: create tables
	if(!$upgrade) {
		$query = "CREATE TABLE IF NOT EXISTS `${cfg['db_table_prefix']}gpx_files` (
		  `id` bigint(64) NOT NULL auto_increment,
		  `user_id` bigint(20) NOT NULL,
		  `visible` tinyint(1) NOT NULL default '1',
		  `name` varchar(255) NOT NULL default '',
		  `size` bigint(20) default NULL,
		  `latitude` double default NULL,
		  `longitude` double default NULL,
		  `timestamp` datetime NOT NULL,
		  `public` tinyint(1) NOT NULL default '1',
		  `description` varchar(255) NOT NULL default '',
		  `inserted` tinyint(1) NOT NULL,
		  PRIMARY KEY  (`id`),
		  KEY `gpx_files_timestamp_idx` (`timestamp`),
		  KEY `gpx_files_visible_public_idx` (`visible`,`public`)
		) ENGINE=MyISAM DEFAULT CHARSET=utf8;";
		$result = mysql_query($query);
		if(!$result) {
		    out(_INST_DB_ERROR. mysql_error(), 3);
		    $mysql_err_count++;
		}
		
		$query = "CREATE TABLE IF NOT EXISTS `${cfg['db_table_prefix']}gpx_import` (
		  `altitude` float default NULL,
		  `trackid` int(11) NOT NULL default '0',
		  `latitude` int(11) NOT NULL default '0',
		  `longitude` int(11) NOT NULL default '0',
		  `gpx_id` bigint(64) NOT NULL default '0',
		  `timestamp` datetime default NULL,
		  `tile` int(11) NOT NULL default '0',
		  `fix` tinyint(3) unsigned default NULL,
		  `sat` tinyint(3) unsigned default NULL,
		  `hdop` float unsigned default NULL,
		  `pdop` float unsigned default NULL,
		  `course` float default NULL,
		  `speed` float default NULL,
		  UNIQUE KEY `timestamp` (`timestamp`),
		  KEY `points_gpxid_idx` (`gpx_id`),
		  KEY `points_tile_idx` (`tile`)
		) ENGINE=MyISAM DEFAULT CHARSET=utf8;";
		$result = mysql_query($query);
		if(!$result) {
		    out(_INST_DB_ERROR. mysql_error(), 3);
		    $mysql_err_count++;
		}
		
		// grant privileges to db user
		if($db_user == "root") {
			$query = "GRANT select,insert,update,delete ON `".$cfg['db_name']."`.* TO 
				'".$cfg['db_user']."'@'".$cfg['db_host']."' identified by '".$cfg['db_password']."'; ";
			$result = mysql_query($query);
			if(!$result) {
			    out(_INST_DB_ERROR. mysql_error(), 3);
			    $mysql_err_count++;
			}
		}
	}
	
	# add code for database upgrades here
	// install or upgrade database for app version 0.3
	if(!$upgrade || $upgrade == 3) {
		HTML::message(_INST_UPGR3_ADD_BOOKM_TBL);
		$query = "CREATE TABLE IF NOT EXISTS `${cfg['db_table_prefix']}bookmarks` (
		  `id` int(11) NOT NULL auto_increment,
		  `name` varchar(32) NOT NULL default '',
		  `url` varchar(255) NOT NULL default '',
		  `latitude` int(11) NOT NULL,
		  `longitude` int(11) NOT NULL,
		  `zoom` tinyint(2) NOT NULL default '12',
		  `timestamp` datetime default NULL,
		  `public` tinyint(1) NOT NULL default '1',
		  PRIMARY KEY  (`id`)
		) ENGINE=MyISAM DEFAULT CHARSET=utf8;";
		$result = mysql_query($query);
		if(!$result) {
		    out(_INST_DB_ERROR. mysql_error(), 3);
		    $mysql_err_count++;
		}

		HTML::message(_INST_UPGR3_ADD_WAYPTS_TBL);
		$query = "CREATE TABLE IF NOT EXISTS `${cfg['db_table_prefix']}waypoints` (
		  `id` int(11) NOT NULL auto_increment,
		  `altitude` float default NULL,
		  `latitude` int(11) NOT NULL default '0',
		  `longitude` int(11) NOT NULL default '0',
		  `timestamp` datetime default NULL,
		  `name` varchar(32) NOT NULL default '',
		  `cmt` varchar(64) NOT NULL default '',
		  `desc` varchar(64) NOT NULL default '',
		  `gpx_id` bigint(64) NOT NULL default '0',
		  `user_id` bigint(20) NOT NULL,
		  `public` tinyint(1) NOT NULL default '1',
		  PRIMARY KEY  (`id`),
		  KEY `gpx_id` (`gpx_id`)
		) ENGINE=MyISAM DEFAULT CHARSET=utf8;";
		$result = mysql_query($query);
		if(!$result) {
		    out(_INST_DB_ERROR. mysql_error(), 3);
		    $mysql_err_count++;
		}
	}
	
	// upgrade database for app version 0.3
	if($upgrade == 3) {
		# add code for database upgrades here
	}
	
	mysql_close($link);
}


if(!$mysql_err_count) {
	echo "<p><img src='images/tick_32.png'> ". _INST_PROG_DB ."<br>\n";
	echo "<a href='done.php'><img src='images/next_32.png' border=0> ". _CMN_CONTINUE ."</a></p>";
}else {
	echo "<p><img src='images/cancel_32.png'> ". _INST_ERROR ."</p>\n";
	echo "<p><a href=\"Javascript:history.back()\"><img src='images/back_32.png' border=0> ". _CMN_PREV ."</a></p>";
}
?>
  <li><?php echo _INST_DONE; ?></li>
</ol>
<?php
include("../foot.html.php");
?>

==> phpMyGPX-0.4.tar.bz2: phpmygpx/installation/install_db.php <==
<?php
/**
* @version $Id: $
* @package osm-things
* @copyright Copyright (C) 2008 Sebastian Klemm.
* @license http://www.gnu.org/copyleft/gpl.html GNU/GPL, see LICENSE.php
*/

define( '_VALID_OSM', TRUE );
define( '_PATH', '../' );
$DEBUG = FALSE;
if($DEBUG) error_reporting(E_ALL);

include("../config.inc.php");
include("../libraries/functions.inc.php");
include("../libraries/html.classes.php");

setlocale (LC_TIME, $cfg['config_locale']);
include("../languages/".get_lang($cfg['config_language']).".php");
include("../head.html.php");

$db_host = strip_tags($_POST['db_host']);
$db_user = strip_tags($_POST['db_user']);
$db_pass = strip_tags($_POST['db_pw']);
$upgrade = strip_tags($_POST['upgrade']);

HTML::heading(_INST_OSM_SETUP._INST_DB_INST, 3);
HTML::message(_INST_GUIDED);
?>

<ol start="1" type="1">
  <li id="done"><?php echo _INST_DB_ACCOUNT; ?><img src='images/tick_12.png'></li>
  <li id="current"><?php echo _INST_DB_CREATE_SETUP; ?></li>
  
  <?php HTML::message(_INST_PROG_INST); ?>

<?php
$mysql_err_count = 0;
// connect to database server
$link = mysql_connect($db_host, $db_user, $db_pass);
if(!$link) {
    out(_INST_DB_CONN_ERROR. mysql_error(), 3);
    $mysql_err_count++;
}else {

	// initial database installation: create database
	if(!$upgrade) {
		$query = "CREATE DATABASE IF NOT EXISTS `".$cfg['db_name']."`;";
		$result = mysql_query($query);
		if(!$result) {
		    out(_INST_DB_ERROR. mysql_error(), 3);
		    $mysql_err_count++;
		}
	}
	
	// select database
	if(!mysql_select_db($cfg['db_name'], $link)) {
	    out(_INST_DB_ERROR. mysql_error(), 3);
	    $mysql_err_count++;
	}
	
	// initial database installation: create tables
	if(!$upgrade) {
		$query = "CREATE TABLE IF NOT EXISTS `${cfg['db_table_prefix']}gpx_files` (
		  `id` bigint(64) NOT NULL auto_increment,
		  `user_id` bigint(20) NOT NULL,
		  `visible` tinyint(1) NOT NULL default '1',
		  `name` varchar(255) NOT NULL default '',
		  `size` bigint(20) default NULL,
		  `latitude` double default NULL,
		  `longitude` double default NULL,
		  `timestamp` datetime NOT NULL,
		  `public` tinyint(1) NOT NULL default '1',
		  `description` varchar(255) NOT NULL default '',
		  `inserted` tinyint(1) NOT NULL,
		  PRIMARY KEY  (`id`),
		  KEY `gpx_files_timestamp_idx` (`timestamp`),
		  KEY `gpx_files_visible_public_idx` (`visible`,`public`)
		) ENGINE=MyISAM CHARSET=utf8;";
		$result = mysql_query($query);
		if(!$result) {
		    out(_INST_DB_ERROR. mysql_error(), 3);
		    $mysql_err_count++;
		}
		
		$query = "CREATE TABLE IF NOT EXISTS `${cfg['db_table_prefix']}gpx_import` (
		  `altitude` float default NULL,
		  `trackid` int(11) NOT NULL default '0',
		  `latitude` int(11) NOT NULL default '0',
		  `longitude` int(11) NOT NULL default '0',
		  `gpx_id` bigint(64) NOT NULL default '0',
		  `timestamp` datetime default NULL,
		  `tile` int(11) NOT NULL default '0',
		  `fix` tinyint(3) unsigned default NULL,
		  `sat` tinyint(3) unsigned default NULL,
		  `hdop` float unsigned default NULL,
		  `pdop` float unsigned default NULL,
		  `course` float default NULL,
		  `speed` float default NULL,
		  UNIQUE KEY `timestamp` (`timestamp`),
		  KEY `points_gpxid_idx` (`gpx_id`),
		  KEY `points_tile_idx` (`tile`)
		) ENGINE=MyISAM CHARSET=utf8;";
		$result = mysql_query($query);
		if(!$result) {
		    out(_INST_DB_ERROR. mysql_error(), 3);
		    $mysql_err_count++;
		}
		
		// grant privileges to db user
		if($db_user == "root") {
			$query = "GRANT select,insert,update,delete ON `".$cfg['db_name']."`.* TO 
				'".$cfg['db_user']."'@'".$cfg['db_host']."' identified by '".$cfg['db_password']."'; ";
			$result = mysql_query($query);
			if(!$result) {
			    out(_INST_DB_ERROR. mysql_error(), 3);
			    $mysql_err_count++;
			}
		}
	}
	
	// install or upgrade database for app version 0.3
	if(!$upgrade || $upgrade >= 3) {
		HTML::message(_INST_UPGR3_ADD_BOOKM_TBL);
		$query = "CREATE TABLE IF NOT EXISTS `${cfg['db_table_prefix']}bookmarks` (
		  `id` int(11) NOT NULL auto_increment,
		  `name` varchar(32) NOT NULL default '',
		  `url` varchar(255) NOT NULL default '',
		  `latitude` int(11) NOT NULL,
		  `longitude` int(11) NOT NULL,
		  `zoom` tinyint(2) NOT NULL default '12',
		  `timestamp` datetime default NULL,
		  `public` tinyint(1) NOT NULL default '1',
		  PRIMARY KEY  (`id`)
		) ENGINE=MyISAM CHARSET=utf8;";
		$result = mysql_query($query);
		if(!$result) {
		    out(_INST_DB_ERROR. mysql_error(), 3);
		    $mysql_err_count++;
		}

		HTML::message(_INST_UPGR3_ADD_WAYPTS_TBL);
		$query = "CREATE TABLE IF NOT EXISTS `${cfg['db_table_prefix']}waypoints` (
		  `id` int(11) NOT NULL auto_increment,
		  `altitude` float default NULL,
		  `latitude` int(11) NOT NULL default '0',
		  `longitude` int(11) NOT NULL default '0',
		  `timestamp` datetime default NULL,
		  `name` varchar(64) NULL default '',
		  `cmt` varchar(255) NULL default '',
		  `desc` varchar(255) NULL default '',
		  `gpx_id` bigint(64) NOT NULL default '0',
		  `user_id` bigint(20) NOT NULL,
		  `public` tinyint(1) NOT NULL default '1',
		  PRIMARY KEY  (`id`),
		  UNIQUE KEY `timestamp` (`timestamp`),
		  KEY `gpx_id` (`gpx_id`)
		) ENGINE=MyISAM CHARSET=utf8;";
		$result = mysql_query($query);
		if(!$result) {
		    out(_INST_DB_ERROR. mysql_error(), 3);
		    $mysql_err_count++;
		}
	}
	
	// upgrade database for app version 0.4
	if($upgrade >= 3) {
		$query = "ALTER TABLE `${cfg['db_table_prefix']}waypoints` 
				ADD UNIQUE (`timestamp`), 
				CHANGE `name` `name` VARCHAR(64) NULL, 
				CHANGE `cmt` `cmt` VARCHAR(255) NULL, 
				CHANGE `desc` `desc` VARCHAR(255) NULL; ";
		$result = mysql_query($query);
		if(!$result) {
		    out(_INST_DB_ERROR. mysql_error(), 3);
		    $mysql_err_count++;
		}
	}
	
	mysql_close($link);
}


if(!$mysql_err_count) {
	echo "<p><img src='images/tick_32.png'> ". _INST_PROG_DB ."<br>\n";
	echo "<a href='done.php'><img src='images/next_32.png' border=0> ". _CMN_CONTINUE ."</a></p>";
}else {
	echo "<p><img src='images/cancel_32.png'> ". _INST_ERROR ."</p>\n";
	echo "<p><a href=\"Javascript:history.back()\"><img src='images/back_32.png' border=0> ". _CMN_PREV ."</a></p>";
}
?>
  <li><?php echo _INST_DONE; ?></li>
</ol>
<?php
include("../foot.html.php");
?>
